@@ -8,8 +8,8 @@ import sys
 sys.path.insert(0, os.path.dirname(os.path.dirname(os.path.abspath(__file__))))
 from fedex.config import FedexConfig
 
-CONFIG_OBJ = FedexConfig(key='ZyNQQFdcxUATOx9L',
-                         password='GtngmKzs4Dk4RYmrlAjrLykwi',
-                         account_number='510087780',
-                         meter_number='118501898',
-                         use_test_server=True)
\ No newline at end of file
+CONFIG_OBJ = FedexConfig(key='txCf12dOfHg99RCt',
+                         password='7A3Q73u6ygBlVKRUkyAEd9qL7',
+                         account_number='248430818',
+                         meter_number='101397836',
+                         use_test_server=False)
\ No newline at end of file
